@@ -8,6 +8,10 @@ function(value.list,value.nom) {
 	  for (i in 1:length(Env$l.var$noms1)) {tkinsert(Env$l.fr3$noms.list,"end",Env$l.var$noms1[i])}
 	  tkdelete(Env$l.fr3$noms.wdg,0,"end")
 	}
+	if (exists("noms.list",where=Env$l.fr4)) {
+	  tkdelete(Env$l.fr4$noms.list,0,"end")
+	  for (i in 1:length(Env$l.var$noms1)) {tkinsert(Env$l.fr4$noms.list,"end",Env$l.var$noms1[i])}
+	}
     } else {
 	msg(text=Env$voc[25,1],type="error")
     }
@@ -15,4 +19,3 @@ function(value.list,value.nom) {
     msg(text=Env$voc[24,1],type="error")
   }
 }
-
